@@ -35,7 +35,7 @@ static int ComputeTrigDuration(TimeTrig const *t);
 
 static int CalledEnterTimezone = 0;
 
-int AdjustTriggerForTimeZone(Trigger *trig, int dse, TimeTrig *tim)
+int AdjustTriggerForTimeZone(Trigger *trig, int dse, TimeTrig *tim, int debug_ok)
 {
     int y, m, d, hour, minute;
     int r;
@@ -59,7 +59,7 @@ int AdjustTriggerForTimeZone(Trigger *trig, int dse, TimeTrig *tim)
     /* Adjust eventstart also */
     trig->eventstart = dse * MINUTES_PER_DAY + tim->ttime;
     SaveAllTriggerInfo(trig, tim, dse, tim->ttime, 1);
-    if (DebugFlag & DB_PRTTRIG) {
+    if (debug_ok && (DebugFlag & DB_PRTTRIG)) {
         fprintf(ErrFp, "%s(%s): Trig(tz_adj %s) = %s, %d %s, %d AT %02d:%02d",
                 GetCurrentFilename(), line_range(LineNoStart, LineNo), trig->tz,
                 get_day_name(dse % 7), tm.tm_mday, get_month_name(tm.tm_mon),
@@ -534,7 +534,7 @@ int DoRem(ParsePtr p)
     }
 
     /* Adjust trigger date/time to time zone */
-    dse = AdjustTriggerForTimeZone(&trig, dse, &tim);
+    dse = AdjustTriggerForTimeZone(&trig, dse, &tim, 1);
 
     /* Add to global OMITs if so indicated */
     if (trig.addomit) {
@@ -546,8 +546,8 @@ int DoRem(ParsePtr p)
     }
     if (PurgeMode) {
         if (trig.expired || (!trig.is_todo && dse < DSEToday)) {
-            if (p->expr_happened) {
-                if (p->nonconst_expr) {
+            if (trig.expr_happened) {
+                if (trig.nonconst_expr) {
                     if (!Hush) {
                         PurgeEchoLine("%s\n", "#!P: Next line may have expired, but contains non-constant expression");
                         PurgeEchoLine("%s\n", "#!P: or a relative SCANFROM clause");
@@ -632,7 +632,7 @@ int DoRem(ParsePtr p)
                     PrintJSONKeyPairInt("time_in_tz", tim.ttime_orig);
                 }
             }
-            if (p->nonconst_expr) {
+            if (trig.nonconst_expr) {
                 PrintJSONKeyPairInt("nonconst_expr", 1);
             }
             if (if_depth) {
@@ -833,6 +833,8 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
     trig->adj_for_last = 0;
     trig->infos = NULL;
     trig->tz = NULL;
+    trig->nonconst_expr = 0;
+    trig->expr_happened = 0;
 
     int parsing = 1;
     while(parsing) {
@@ -1097,6 +1099,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
             s->expr_happened = 1;
             nonconst_debug(s->nonconst_expr, tr("OMITFUNC counts as a non-constant expression"));
             s->nonconst_expr = 1;
+            trig->nonconst_expr = 1;
             DBufFree(&buf);
             break;
 
@@ -1201,6 +1204,12 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
         }
     }
 
+    if (s->nonconst_expr) {
+        trig->nonconst_expr = 1;
+    }
+    if (s->expr_happened) {
+        trig->expr_happened = 1;
+    }
     if (trig->need_wkday && trig->wd == NO_WD) {
         Eprint("Weekday name(s) required");
         return E_PARSE_ERR;
@@ -1237,7 +1246,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
         }
     }
 
-    if (!s->nonconst_expr) {
+    if (!trig->nonconst_expr) {
         if (trig->y != NO_YR && trig->m != NO_MON && trig->d != NO_DAY && trig->until != NO_UNTIL) {
             if (DSE(trig->y, trig->m, trig->d) > trig->until) {
                 Wprint(tr("Warning: UNTIL/THROUGH date earlier than start date"));
@@ -1273,10 +1282,10 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
 
     /* Remove leading ! from TZ spec */
     if (trig->tz && *trig->tz == '!') {
-        char *s = (char *) trig->tz;
-        while (*s) {
-            *s = *(s+1);
-            s++;
+        char *stz = (char *) trig->tz;
+        while (*stz) {
+            *stz = *(stz+1);
+            stz++;
         }
     }
     return OK;
@@ -1497,6 +1506,7 @@ static int ParseScanFrom(ParsePtr s, Trigger *t, int type)
             s->expr_happened = 1;
             nonconst_debug(s->nonconst_expr, tr("Relative SCANFROM counts as a non-constant expression"));
             s->nonconst_expr = 1;
+            t->nonconst_expr = 1;
             return OK;
 
         default:
